#
# spec file for package python-tblib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -%{flavor}
%bcond_without  test
%else
%define psuffix %{nil}
%bcond_with     test
%endif
%{?sle15_python_module_pythons}
Name:           python-tblib%{?psuffix}
Version:        3.0.0
Release:        2.3
Summary:        Traceback serialization library
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/ionelmc/python-tblib
Source:         https://files.pythonhosted.org/packages/source/t/tblib/tblib-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/ionelmc/python-tblib/pull/77 vendore reraise() from six
Patch0:         vendore-reraise-from-six.patch
# PATCH-FIX-UPSTREAM https://github.com/ionelmc/python-tblib/issues/74 More aggressive location stripping. Ref #74.
Patch1:         more-aggressive-location-stripping.patch
# PATCH-FIX-FEDORA https://src.fedoraproject.org/rpms/python-tblib/blob/rawhide/f/0001-test_pickle_exception-even-harder-location-stripping.patch
Patch2:         test_pickle_exception-even-harder-location-stripping.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Twisted}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tblib == %{version}}
%endif
%python_subpackages

%description
Traceback serialization library.

It allows you to:

* Pickle  tracebacks and raise exceptions with pickled tracebacks in
  different processes. This allows better error handling when running
  code over multiple processes (imagine multiprocessing, billiard,
  futures, celery etc).
* Create traceback objects from strings (the ``from_string`` method).
  *No pickling is used*.
* Serialize tracebacks to/from plain dicts (the ``from_dict`` and
  ``to_dict`` methods). *No pickling is used*.
* Raise the tracebacks created from the aforementioned sources.

Again, note that using the pickle support is completely optional. You
are solely responsible for security problems should you decide to use
the pickle support.

%prep
%autosetup -p1 -n tblib-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc AUTHORS.rst CHANGELOG.rst README.rst
%license LICENSE
%{python_sitelib}/tblib
%{python_sitelib}/tblib-%{version}*-info
%endif

%changelog
* Mon Sep  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Cherry-pick patch from Fedora to fix testsuite with Python 3.13
  * test_pickle_exception-even-harder-location-stripping.patch
* Fri May 31 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up SPEC file.
* Fri May 17 2024 Markéta Machová <mmachova@suse.com>
- Update to 3.0.0
  * Removed support for legacy Pythons (2.7 up to 3.7) and added Pythons
    3.11 and 3.12 in the test grid.
  * Added support for __context__, __suppress_context__ and __notes__.
  * Added the get_locals argument to tblib.pickling_support.install(),
    tblib.Traceback and tblib.Frame.
- Add vendore-reraise-from-six.patch to get rid of six
- Add more-aggressive-location-stripping.patch to fix test failure
- Standardize multibuild
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Sep 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.7.0:
  * Add more attributes to ``Frame`` and ``Code`` objects for pytest compatibility.
* Sun Dec 15 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Move the Twisted test out of the main package to avoid the
  Twisted dependency chain.
* Sun Dec 15 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- version update to 1.6.0
  * When pickling an Exception, also pickle its traceback and the Exception
    chain (raise ... from ...). Contributed by Guido Imperiale in #53.
- version update to 1.5.0
  * Added support for Python 3.8. Contributed by Victor Stinner in #42.
  * Removed support for end of life Python 3.4.
  * Few CI improvements and fixes.
* Mon May  6 2019 pgajdos@suse.com
- version update to 1.4.0
  * Remove support for end of life Python 3.3.
  * Fixed tests for Python 3.7. Contributed by Elliott Sales de Andrade in
    `#36 <https://github.com/ionelmc/python-tblib/issues/36>`_.
  * Fixed compatibility issue with Twised (``twisted.python.failure.Failure``
    expected a ``co_code`` attribute).
- deleted patches
  - 0001-Patch-tests-against-Python-3.7.patch (upstreamed)
* Sun Mar  3 2019 John Vandenberg <jayvdb@gmail.com>
- Remove bcond_with test preventing the tests from running,
  and fix the %%check
- Remove unnecessary dependency on tox, flake8 and 9 other deps
- Add 0001-Patch-tests-against-Python-3.7.patch to workaround
  Python 3.7 test failure.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Mar 19 2018 sebix+novell.com@sebix.at
- Use %%license macro for license.
* Mon Aug 14 2017 toddrme2178@gmail.com
- Initial version
